/**************************************************************************
 * camera.h
 * Description: This file contains all fucntions fro camera.c
 * 		and any macros necessary.
 *
 * Written by: 	Hector Nuez, Sina Karimi, Ryan Campbell
 * Date: 	February 24, 2010
 ***************************************************************************/

#ifndef _CAMERA_H
#define _CAMERA_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

extern "C"
{
#include "parts/m55800/lib_m55800.h"
#include "drivers/capture/capture.h"
#include "parts/m55800/eb55.h"
#include "periph/ebi/lib_ebi.h"
#include "periph/usart/usart.h"

#include "os_cpu.h"
#include "ucos_ii.h"

#include "globals.h"
}

#include "ftp.h"

//C328-7640 Cammera comands to comunicate between comPort and cammera.
//Start transmission byte, it precedes any comand sent to the cammera.
#define TRANSMIT		0xAA

//Camera Initialization
#define INITIALIZE 		0x01
//PARMETER 1 static
#define INIT_PARM1		0x00
//PARAMETER 2: Choose the Color Type
#define GRAY_2_BIT		0x01
#define GRAY_4_BIT		0x02
#define GRAY_8_BIT		0x03
#define COLOR_12_BIT		0x05
#define COLOR_16_BIT		0x06
#define COLOR_JPEG		0x07
//PARAMETER 3: Choose the Preview Resolution
#define PREV_RES_80x60		0x01
#define PREV_RES_160x120	0x03
//PARAMETER 4: Choose the JPEG Resolution
#define JPEG_RES_80x64		0x01
#define JPEG_RES_160x128	0x03
#define JPEG_RES_320x240	0x05
#define JPEG_RES_640x480	0x07

//Get Picture command
#define GET_PICTURE 		0x04
//PARAMETER 1: Picture Type
#define PIC_SNAPSHOT		0x01
#define PIC_PREVIEW		0x02
#define PIC_JPEG_PREV		0x05
//ALL other parameters are:
#define PIC_PARAM2		0x00
#define PIC_PARAM3		0x00
#define PIC_PARAM4		0x00

//Snapshot: keeps a single JPEG frame of data in the buffer after
//reciving this command
#define SNAPSHOT		0x05
//PARAMETER 1: Snapshot Type
#define SNAP_COMPRESS		0x00
#define SNAP_UNCOMPRESS		0x01
//PARAMETER 2: Lower byte of Skip Frame Counter
//Will set it to 0 skips fpr now
#define SNAP_SKIP_LOW		0x00
//PARAMETER 3: High byte of Skip Frame Counter
//Will set it to 0 skips fpr now
#define SNAP_SKIP2_HIGH		0x00
//PARAMETER 4:
#define SNAP_PARAM4		0x00

//Set Package Size: Used to change the size of data package which is
//used to transmit the JPEG image
#define SET_PACKG_SIZE		0x06
//PARAMETER 1:
#define SET_PACKG_PARAM1	0x08
//PARAMETER 2: Low Byte Package Size
//----------For 64 as the default----------------------
#define PACKG_SIZE_64_LOW	0x40
//PARAMETER 3: High Byte Package Size
#define PACKG_SIZE_64_HIGH	0x00
//----------For 512 as the default----------------------
#define PACKG_SIZE_512_LOW	0x00
//PARAMETER 3: High Byte Package Size
#define PACKG_SIZE_512_HIGH	0x02
//PARAMETER 4:
#define SET_PACKG_PARAM4	0x00

//Set Baud Rate
#define SET_BAUD_RATE		0x07
//For different Baud rates, choose the correct dividers:
//PARAMETER 1: 1st Divider, choose desired Baud rate
#define BAUD_7200_DIV1		0xFF
#define BAUD_9600_DIV1		0xBF
#define BAUD_14400_DIV1		0x7F
#define BAUD_19200_DIV1		0x5F
#define BAUD_28800_DIV1		0x3F
#define BAUD_38400_DIV1		0x2F
#define BAUD_57600_DIV1		0x1F
#define BAUD_115200_DIV1 	0x0F
//PARAMETER 2: 2nd Divider Always = 0x01
#define BAUD_ALL_DIV2		0x01
//PARAMETER 3:
#define SET_BAUD_PARAM3		0x00
//PARAMETER 4:
#define SET_BAUD_PARAM4		0x00

//Reset: Resets the cammera either ALL including registers or RESTART by
//reseting the state machine sequence
#define RESET			0x08
//PARAMETER 1: Reset Type
#define RST_ALL			0x00
#define RST_RESTART		0x00
//PARAMETER 2:
#define RST_PARAM2		0x00
//PARAMETER 3:
#define RST_PARAM3		0x00
//PARAMETER 4:
#define RST_PARAM4		0x00

//Cammera turns off after this command, revirted with a SYNC command
#define POWER_OFF		0x09
//PARAMETER 1:
#define POWER_OFF_PARAM1	0x00
//PARAMETER 2:
#define POWER_OFF_PARAM2	0x00
//PARAMETER 3:
#define POWER_OFF_PARAM3	0x00
//PARAMETER 4:
#define POWER_OFF_PARAM4	0x00


#define DATA			0x0A
//PARAMETER 1: Data Type
#define DATA_SNAPSHOT		0x01
#define DATA_PREV		0x02
#define DATA_JPEG		0x05
//Lenght Chossen by Number of Package = Image size/(Package Size - 6)
//				      = 8000 bytes/ (64-6) = 137 = 0x89
//PARAMETER 2: Lenght Byte 0
#define DATA_LEN1		0x89
//PARAMETER 3: Lenght Byte 1
#define DATA_LEN2		0x00
//PARAMETER 4: Lenght Byte 2
#define DATA_LEN2		0x00

//Synchronize: command used to make a connection between host and cammera
#define SYNC			0x0D
//PARAMETER 1:
#define SYNC_PARAM1		0x00
//PARAMETER 2:
#define SYNC_PARAM2		0x00
//PARAMETER 3:
#define SYNC_PARAM3		0x00
//PARAMETER 4:
#define SYNC_PARAM4		0x00

//Acknowledge: Indicates a succesfull operation
#define ACK			0x0E
//PARAMETER 1: Command ID, is the ID of the command being acknowledge,
// 		thus set it to the propper commandID
//PARAMETER 2: ACK Counter, Not used
#define ACK_PARAM2		0x00
//PARAMETER 3: Either Package ID Byte 0 or simple 0x00 if not a Data Command ack.
#define ACK_PARAM3		0x00
//PARAMETER 4: Either Package ID Byte 1 or simple 0x00 if not a Data Command ack.
#define ACK_PARAM4		0x00

//Not Acknowledge: Indicates currupted or errors in transmission
#define NAK			0x0F
//PARAMETER 1:
#define NAK_PARAM1		0x00
//PARAMETER 2: NAK Counter, Not used
#define NAK_PARAM2		0x00
//PARAMETER 3: Error Number
#define NAK_ERR_1		0x01
#define NAK_ERR_2		0x02
#define NAK_ERR_3		0x03
#define NAK_ERR_4		0x04
#define NAK_ERR_5		0x05
#define NAK_ERR_6		0x06
#define NAK_ERR_7		0x07
#define NAK_ERR_8		0x08
#define NAK_ERR_9		0x09
#define NAK_ERR_10		0x0A
#define NAK_ERR_11		0x0B
#define NAK_ERR_12		0x0C
#define NAK_ERR_13		0x0D
#define NAK_ERR_14		0x0F
#define NAK_ERR_15		0x10
#define NAK_ERR_16		0x11
#define NAK_ERR_17		0xF0
#define NAK_ERR_18		0xF1
#define NAK_ERR_19		0xF5
#define NAK_ERR_20		0xFF
#define NAK_ERR_MSG_1		"Picture Type Error"
#define NAK_ERR_MSG_2 		"Picture Up Scale"
#define NAK_ERR_MSG_3 		"Picture Scale Error"
#define NAK_ERR_MSG_4 		"Unexpected Reply"
#define NAK_ERR_MSG_5		"Send Picture Timeout"
#define NAK_ERR_MSG_6 		"Unexpected Command"
#define NAK_ERR_MSG_7 		"SRAM JPEG Type Error"
#define NAK_ERR_MSG_8		"SRAM JPEG Size Error"
#define NAK_ERR_MSG_9 		"Picture Format Error"
#define NAK_ERR_MSG_10 		"Picture Size Error"
#define NAK_ERR_MSG_11 		"Parameter Error"
#define NAK_ERR_MSG_12 		"Send Register Timeout"
#define NAK_ERR_MSG_13 		"Command ID Error"
#define NAK_ERR_MSG_14 		"Picture Not Ready"
#define NAK_ERR_MSG_15 		"Transfer Package Number Error"
#define NAK_ERR_MSG_16 		"Set Transfer Package Size Wrong"
#define NAK_ERR_MSG_17 		"Command Header Error"
#define NAK_ERR_MSG_18 		"Command Length Error"
#define NAK_ERR_MSG_19 		"Send Picture Error"
#define NAK_ERR_MSG_20 		"Send Command Error"
//PARAMETER 4:
#define NAK_PARAM4		0x00

//Light Frequency: Sent by Host to change cammera's ligth frequency
#define LIGHT_FREQ		0x13
//PARAMETER 1: Frequency Type
#define LIGHT_FREQ_50HZ		0x00
#define LIGHT_FREQ_60HZ		0x01
//PARAMETER 2:
#define LIGHT_PARAM2		0x00
//PARAMETER 3:
#define LIGHT_PARAM3		0x00
//PARAMETER 4:
#define LIGHT_PARAM4		0x00

//Command ID for ACK returned to cammera when image data was received
#define DATA_RECV 		0x00

//Host comPort Baud rate selection
//Since CD (clock Divisor) in USART Baud Rate Register (US_BRGR)
// is: CD = CLK/(BaudRate*16) and CLK chossen CLK = 32.9 MHz,
#define BAUDRATE_7200 		286
#define BAUDRATE_9600 		214
#define BAUDRATE_14400		134
#define BAUDRATE_19200		107
#define BAUDRATE_28800		71
#define BAUDRATE_38400		53
#define BAUDRATE_57600		34
#define BAUDRATE_115200		18

//Host comPort Tx Time Guard selections
#define TIME_GUARD_DISABLE 	0

//Host comPort Rx Time Out selections
//form at91_recv_buffer description:
//<timeout> = the inter-character time delay in number
//            of byte
//for 14400 use 10
//for 57600 use 40
#define TIME_OUT 		40


//RXRDY mask for US_CSR chanel status register
#define RECV_READY 		0x0001

#define NOT_ACK 		0x00
#define TRUE 			1
#define FALSE 			0

#define DATA_PACKG_SIZE 	512
#define DATA_PACKG_OVERHEAD 	10
#define RX_BUFFER_OVERHEAD 	10

#define ONE_COMMAND_LEN		6
#define TWO_COMMANDS_LEN	12

#define DATA_PACKG_HEADER	6

#define CAMERA_MAX_SYNC_TIMES 	40

extern FTP_Client ftp_client;

class Camera;

class Camera {
    
private:
    PioCtrlDesc pioCtrl_desc;
    UsartDesc comPort;
    OS_EVENT *  CameraSem;
    char picBuffer[20000];

    int is_ack(char * rxBuffer, u_int commandID);
    int is_sync(char * rxBuffer);
    int get_dataLength(char * dataBuffer);
    void recv_image_package(char * rxBuffer, int rxBufferLen, int counter);
    void send_command(char * txBuffer);
    int send_and_recv(char * txBuffer, char * rxBuffer, char ** pRxBuffer, u_int recvByteNum);
    void print_Buffer(char * rxBuffer);
    int align_buffer(char * dataBuffer, char ** pAlignedBuffer, u_int timeOut);
    void save(char * pPicBuffer, int dataLength, char * filePath);

    int send_SYNC();
    void send_ACK(u_int commandID, char * packgId);
    void send_NAK(u_int error);
    int send_INITIALIZE();
    int send_POWER_OFF();
    int send_RESET();
    int send_GET_PICTURE(int * pDataLength);
    int send_SET_PACKG_SIZE();
    int send_SNAPSHOT();



    
public:
    Camera();
    void Init();
    int powerOn();
    int powerOff();
    int reset();
    int get_picture(char * filePath);
    void takePictures(int num_pics);
  
};

#endif  /*camera_h*/


/* This function sends a SYNC command to the cammera to make a conection */

/* This function initializes the camera comunication through the
 * PIO controller (USART)*/

/* is_ack is a function that read the next 6 consecutive command bytes sent by
 * the cammera. Then it determines if the command is an ACK.
 * INPUT: the comport pointer, and the expected CommandId to be acknowledge
 * OUTPUT: TURE if is a valid ACK and for the command ID expected, 
 *         or a NOT_ACK if not ACK.
 */



/*DRSCRIPTION: This function read the six consecutive bytes sent
 *		by the cammera to the host
 *INPUT: The comport pointer, and the pointer to the receiver buffer
 *OUTPUT: None
 */


    /*Description: retreived the length of the image data which
     *             is ready for transmitting out to the host.
     *INPUT: Pointer to the start of the command data in the received buffer
     *OUTPUT: Returns	 an integer containing length of the data in bytes,
     *        or zero if the data in the buffer is not valid 
     */

/*Setting the data package to 512 Bytes:
  where: packgId (2 Bytes),
  data size (2 Bytes), indicates how many bytes are in the image data info.
  Image Data (up to 512-6=506 Bytes), Image information
  Verify Code (2 Bytes), code = lowbyte(sum(byte[0] to byte[N-2]))
  Could change the size to a lower number. 512 id the highest available.
  */		
