/*************************************************
 * main.c for SmartHome
 * Sina Karimi, Ryan Campbell, Hector Nunez
 * Feb, 2010
 *
 *************************************************/

#include "main.h"

#define HTTPD_STK_SIZE	1024   /*rediculously large (24000 works), but we create big buffers for the
				  webserver and the camera... */

#define SENSOR_STK_SIZE 1024

extern "C"
{
    void c_handler(void);
    extern void enable_interrupts(void);
}

INT8U MotionSensorTaskStart();
static void MotionSensorTask(void *p_args);
void MotionSensorInit(void);

/*uC Globals */
OS_STK  HttpdTaskStk[HTTPD_STK_SIZE];
OS_STK	MotionSensorTaskStk[SENSOR_STK_SIZE];
OS_EVENT *  MotionSensorSem;

//*----------------------------------------------------------------------------
//* Function Name       : main
//* Object              : Main function of the SmartHome
//* Input Parameters    : none
//* Output Parameters   : True
//*----------------------------------------------------------------------------
int main( void )
{
    INT8U  err = OS_NO_ERR;

    enable_interrupts();

    /* turn off LEDs */
    at91_pio_open ( &PIOB_DESC, LED_MASK, PIO_OUTPUT ) ;
    at91_pio_write (&PIOB_DESC, LED_MASK, LED_OFF ) ;

    OSInit();
    
    err = HttpdTaskStart();
    err = MotionSensorTaskStart();

#if OS_TASK_NAME_SIZE > 11
    OSTaskNameSet(HTTP_TASK_PRIO, (INT8U*)"Start Task", &err);
#endif

    OSStart();     /* Start multitasking (i.e. give control to uC/OS-II) */

    return 0;
    
} /* main */

INT8U HttpdTaskStart()
{
    INT8U  err = OS_NO_ERR;


    err = OSTaskCreateExt(HttpdTask,
	    NULL,
	    (OS_STK *)&HttpdTaskStk[HTTPD_STK_SIZE-1],
	    HTTP_TASK_PRIO,
	    HTTP_TASK_PRIO,
	    (OS_STK *)&HttpdTaskStk[0],
	    HTTPD_STK_SIZE,
	    NULL,
	    OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR);


    return err;
}

INT8U MotionSensorTaskStart()
{
    INT8U  err = OS_NO_ERR;

    err = OSTaskCreateExt(MotionSensorTask,
	    NULL,
	    (OS_STK *)&MotionSensorTaskStk[SENSOR_STK_SIZE-1],
	    MOTION_SENSOR_TASK_PRIO,
	    MOTION_SENSOR_TASK_PRIO,
	    (OS_STK *)&MotionSensorTaskStk[0],
	    SENSOR_STK_SIZE,
	    NULL,
	    OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR);

    return err;
}


static void MotionSensorTask(void *p_args)
{
    INT8U err;
    OS_SEM_DATA semdata;

    BSP_Init();

    MotionSensorSem = OSSemCreate(0);
#ifdef DEBUG
    if(MotionSensorSem == NULL)
	printf(" Ahh, OSSemCreate failed!\n");
    else
	printf("OSSemCreate succeeded\n");
#endif

    /* we want the motion sensor semaphore to block until the
     * interrupt releases it, so pend now
     */
	
    //MotionSensorInit();
    
    while(TRUE)
    {
	/* block until motion sensor interrupt releases semaphore */
	OSSemQuery(MotionSensorSem, &semdata);
	printf("semdata.OSCnt = %d\n", semdata.OSCnt);
	
	OSSemPend(MotionSensorSem, 0, &err);

	at91_pio_write (&PIOB_DESC, LED6, LED_ON );

	/*take some pictures */
#ifdef DEBUG
	printf("taking a picture in MotionSensorTask\n");
#endif
	camera.takePictures(1);

	at91_pio_write (&PIOB_DESC, LED6, LED_OFF );

	OSTimeDly(OS_TICKS_PER_SEC);
	
    }/* while */

} /* MotionSensorTask */


void MotionSensorInit(void)
{
    //set up interrupt handlers

    at91_extirq_open(&IRQ1_DESC, //depending on which IRQ we use
	    5, //priority
	    AIC_SRCTYPE_EXT_POSITIVE_EDGE, //trigger on rising edge
	    c_handler //our interrupt service routine
	    );

}/* MotionSensorInit */



static void HttpdTask(void *p_arg)
{
    BSP_Init();

    wiznet_ebi_setup();		/* setup the CSR for the wiznet */
    iinchip_init();  		/* initiate W5300 */
    wiznet_init();		/* initiate Wiznet Networking Conf */

#if OS_TASK_STAT_EN > 0
    OSStatInit();       /* determine CPU capacity */
#endif


    at91_pio_write (&PIOB_DESC, LED_MASK, LED_OFF ) ; /*turn all the LEDs off*/
     
    while(TRUE)
    {
	httpd.run();
	//OSTimeDly(OS_TICKS_PER_SEC/1000);
	OSTimeDly(1);
    }
    
} /* HttpdTask */


void wiznet_ebi_setup()
{
    ChipSelectDesc cs_desc;
     
    // -- set register values for CSR
    cs_desc.base_address = __DEF_IINCHIP_MAP_BASE__; // 0x00400000 
    cs_desc.cs_id = 2; //NCS2 is used for wiznet
    cs_desc.wait_state = 8; // was 8
    cs_desc.data_float = 1; // start with 0, same as above
    cs_desc.page_size = CS_1_MBYTE;
    cs_desc.byte_access_type = CS_BYTE_SELECT;
    cs_desc.data_bus_width = CS_16_BIT_BUS;
    
    // -- set up chip select register 
    at91_chip_select_open (&cs_desc);

} /* wiznet_ebi_setup */

void wiznet_init()
{
    int i;
    
    uint8 tx_mem_conf[8] = {8,8,8,8,8,8,8,8};		// for setting TMSR regsiter
    uint8 rx_mem_conf[8] = {8,8,8,8,8,8,8,8};		// for setting RMSR regsiter
    
    uint8 ip[4] = {192,168,10,100};			// for setting SIP register
    uint8 gw[4] = {192,168,10,1};			// for setting GAR register
    uint8 sn[4] = {255,255,255,0};			// for setting SUBR register
    uint8 mac[6] = {0xF0,0xE1,0xD2,0xC3,0xB4,0xA5};	// for setting SHAR register
     
    if(!sysinit(tx_mem_conf,rx_mem_conf))           
    {
#ifdef DEBUG
	printf("MEMORY CONFIG ERR.\r\n");
#endif
    }

    setMR(getMR()|MR_FS);				// If Little-endian, set MR_FS.
    setSHAR(mac);					// set source hardware address

    /* configure network information */
    setGAR(gw);						// set gateway IP address
    setSUBR(sn);					// set subnet mask address
    setSIPR(ip);					// set source IP address

    getSHAR(mac);					// get source hardware address 
    getGAR(gw);						// get gateway IP address      
    getSUBR(sn);					// get subnet mask address     
    getSIPR(ip);					// get source IP address       

#ifdef DEBUG
    printf("SHAR : %02x:%02x:%02x:%02x:%02x:%02x\r\n",mac[0],mac[1],mac[2],mac[3],mac[4],mac[5]);
    printf("GWR  : %d.%d.%d.%d\r\n",gw[0],gw[1],gw[2],gw[3]);
    printf("SUBR : %d.%d.%d.%d\r\n",sn[0],sn[1],sn[2],sn[3]);
    printf("SIPR : %d.%d.%d.%d\r\n",ip[0],ip[1],ip[2],ip[3]);
#endif
    
    for( i = 0; i < MAX_SOCK_NUM; i++)
    {
	disconnect(i);
	close(i);
    }

    at91_pio_write (&PIOB_DESC, LED8, LED_ON );
    
} /* wiznet_init */

void c_handler(void)
{
    OS_SEM_DATA semdata;
    
    //at91_pio_write (&PIOB_DESC, LED6, LED_ON );

    OSSemQuery(MotionSensorSem, &semdata);
    if (semdata.OSCnt < 1)
	OSSemPost(MotionSensorSem);
    
    AIC_IVR = 0;
    AIC_ICCR = (1 << IRQ1_ID);
    AIC_EOICR = 0;

    //at91_pio_write (&PIOB_DESC, LED6, LED_OFF );
 
} /* c_handler */

